@@ -24,6 +24,7 @@ use {
     rand::{seq::SliceRandom, Rng},
     solana_runtime::bloom::{AtomicBloom, Bloom},
     solana_sdk::{packet::PACKET_DATA_SIZE, pubkey::Pubkey, timing::timestamp},
+    solana_streamer::socket::SocketAddrSpace,
     std::{
         cmp,
         collections::{HashMap, HashSet},
@@ -263,6 +264,7 @@ impl CrdsGossipPush {
         self_shred_version: u16,
         network_size: usize,
         ratio: usize,
+        socket_addr_space: &SocketAddrSpace,
     ) {
         const BLOOM_FALSE_RATE: f64 = 0.1;
         const BLOOM_MAX_BITS: usize = 1024 * 8 * 4;
@@ -274,7 +276,14 @@ impl CrdsGossipPush {
         let need = Self::compute_need(self.num_active, self.active_set.len(), ratio);
         let mut new_items = HashMap::new();
         let (weights, peers): (Vec<_>, Vec<_>) = self
-            .push_options(crds, self_id, self_shred_version, stakes, gossip_validators)
+            .push_options(
+                crds,
+                self_id,
+                self_shred_version,
+                stakes,
+                gossip_validators,
+                socket_addr_space,
+            )
             .into_iter()
             .unzip();
         if peers.is_empty() {
@@ -315,6 +324,7 @@ impl CrdsGossipPush {
         self_shred_version: u16,
         stakes: &HashMap<Pubkey, u64>,
         gossip_validators: Option<&HashSet<Pubkey>>,
+        socket_addr_space: &SocketAddrSpace,
     ) -> Vec<(u64, &'a ContactInfo)> {
         let now = timestamp();
         let mut rng = rand::thread_rng();
@@ -336,7 +346,7 @@ impl CrdsGossipPush {
             })
             .filter(|info| {
                 info.id != *self_id
-                    && ContactInfo::is_valid_address(&info.gossip)
+                    && ContactInfo::is_valid_address(&info.gossip, socket_addr_space)
                     && self_shred_version == info.shred_version
                     && gossip_validators.map_or(true, |gossip_validators| {
                         gossip_validators.contains(&info.id)
@@ -547,7 +557,16 @@ mod test {
         )));
 
         assert_eq!(crds.insert(value1.clone(), now), Ok(()));
-        push.refresh_push_active_set(&crds, &HashMap::new(), None, &Pubkey::default(), 0, 1, 1);
+        push.refresh_push_active_set(
+            &crds,
+            &HashMap::new(),
+            None,
+            &Pubkey::default(),
+            0,
+            1,
+            1,
+            &SocketAddrSpace::Unspecified,
+        );
 
         assert!(push.active_set.get(&value1.label().pubkey()).is_some());
         let value2 = CrdsValue::new_unsigned(CrdsData::ContactInfo(ContactInfo::new_localhost(
@@ -557,7 +576,16 @@ mod test {
         assert!(push.active_set.get(&value2.label().pubkey()).is_none());
         assert_eq!(crds.insert(value2.clone(), now), Ok(()));
         for _ in 0..30 {
-            push.refresh_push_active_set(&crds, &HashMap::new(), None, &Pubkey::default(), 0, 1, 1);
+            push.refresh_push_active_set(
+                &crds,
+                &HashMap::new(),
+                None,
+                &Pubkey::default(),
+                0,
+                1,
+                1,
+                &SocketAddrSpace::Unspecified,
+            );
             if push.active_set.get(&value2.label().pubkey()).is_some() {
                 break;
             }
@@ -570,7 +598,16 @@ mod test {
             ));
             assert_eq!(crds.insert(value2.clone(), now), Ok(()));
         }
-        push.refresh_push_active_set(&crds, &HashMap::new(), None, &Pubkey::default(), 0, 1, 1);
+        push.refresh_push_active_set(
+            &crds,
+            &HashMap::new(),
+            None,
+            &Pubkey::default(),
+            0,
+            1,
+            1,
+            &SocketAddrSpace::Unspecified,
+        );
         assert_eq!(push.active_set.len(), push.num_active);
     }
     #[test]
@@ -590,7 +627,14 @@ mod test {
             stakes.insert(id, i * 100);
             push.last_pushed_to.put(id, time);
         }
-        let mut options = push.push_options(&crds, &Pubkey::default(), 0, &stakes, None);
+        let mut options = push.push_options(
+            &crds,
+            &Pubkey::default(),
+            0,
+            &stakes,
+            None,
+            &SocketAddrSpace::Unspecified,
+        );
         assert!(!options.is_empty());
         options.sort_by(|(weight_l, _), (weight_r, _)| weight_r.partial_cmp(weight_l).unwrap());
         // check that the highest stake holder is also the heaviest weighted.
@@ -641,7 +685,14 @@ mod test {
 
         // shred version 123 should ignore nodes with versions 0 and 456
         let options = node
-            .push_options(&crds, &me.label().pubkey(), 123, &stakes, None)
+            .push_options(
+                &crds,
+                &me.label().pubkey(),
+                123,
+                &stakes,
+                None,
+                &SocketAddrSpace::Unspecified,
+            )
             .iter()
             .map(|(_, c)| c.id)
             .collect::<Vec<_>>();
@@ -651,7 +702,14 @@ mod test {
 
         // spy nodes should not push to people on different shred versions
         let options = node
-            .push_options(&crds, &spy.label().pubkey(), 0, &stakes, None)
+            .push_options(
+                &crds,
+                &spy.label().pubkey(),
+                0,
+                &stakes,
+                None,
+                &SocketAddrSpace::Unspecified,
+            )
             .iter()
             .map(|(_, c)| c.id)
             .collect::<Vec<_>>();
@@ -688,6 +746,7 @@ mod test {
             0,
             &stakes,
             Some(&gossip_validators),
+            &SocketAddrSpace::Unspecified,
         );
 
         assert!(options.is_empty());
@@ -700,6 +759,7 @@ mod test {
             0,
             &stakes,
             Some(&gossip_validators),
+            &SocketAddrSpace::Unspecified,
         );
         assert!(options.is_empty());
 
@@ -711,6 +771,7 @@ mod test {
             0,
             &stakes,
             Some(&gossip_validators),
+            &SocketAddrSpace::Unspecified,
         );
 
         assert_eq!(options.len(), 1);
@@ -727,7 +788,16 @@ mod test {
             0,
         )));
         assert_eq!(crds.insert(peer.clone(), now), Ok(()));
-        push.refresh_push_active_set(&crds, &HashMap::new(), None, &Pubkey::default(), 0, 1, 1);
+        push.refresh_push_active_set(
+            &crds,
+            &HashMap::new(),
+            None,
+            &Pubkey::default(),
+            0,
+            1,
+            1,
+            &SocketAddrSpace::Unspecified,
+        );
 
         let new_msg = CrdsValue::new_unsigned(CrdsData::ContactInfo(ContactInfo::new_localhost(
             &solana_sdk::pubkey::new_rand(),
@@ -762,7 +832,16 @@ mod test {
             push.process_push_message(&mut crds, &Pubkey::default(), peers[2].clone(), now),
             Ok(())
         );
-        push.refresh_push_active_set(&crds, &HashMap::new(), None, &Pubkey::default(), 0, 1, 1);
+        push.refresh_push_active_set(
+            &crds,
+            &HashMap::new(),
+            None,
+            &Pubkey::default(),
+            0,
+            1,
+            1,
+            &SocketAddrSpace::Unspecified,
+        );
 
         // push 3's contact info to 1 and 2 and 3
         let expected: HashMap<_, _> = vec![
@@ -784,7 +863,16 @@ mod test {
             0,
         )));
         assert_eq!(crds.insert(peer.clone(), 0), Ok(()));
-        push.refresh_push_active_set(&crds, &HashMap::new(), None, &Pubkey::default(), 0, 1, 1);
+        push.refresh_push_active_set(
+            &crds,
+            &HashMap::new(),
+            None,
+            &Pubkey::default(),
+            0,
+            1,
+            1,
+            &SocketAddrSpace::Unspecified,
+        );
 
         let new_msg = CrdsValue::new_unsigned(CrdsData::ContactInfo(ContactInfo::new_localhost(
             &solana_sdk::pubkey::new_rand(),
@@ -811,7 +899,16 @@ mod test {
             0,
         )));
         assert_eq!(crds.insert(peer, 0), Ok(()));
-        push.refresh_push_active_set(&crds, &HashMap::new(), None, &Pubkey::default(), 0, 1, 1);
+        push.refresh_push_active_set(
+            &crds,
+            &HashMap::new(),
+            None,
+            &Pubkey::default(),
+            0,
+            1,
+            1,
+            &SocketAddrSpace::Unspecified,
+        );
 
         let mut ci = ContactInfo::new_localhost(&solana_sdk::pubkey::new_rand(), 0);
         ci.wallclock = 1;
